function [Xavg, Xstd] = runstats(X,n)
% RUNAVG Running Statistics.
% RUNAVG(X,n) calculates a running average and standard deviation over n data 
% points of vector X and outputs it in the matrix stats.  In the first
% column of stats is the average, in the second the standard deviation.
% The algorithm is efficient because it uses the average and standard
% deviation of the previous runnning statistics data point.
% Up to the first n data points the average and standard deviation of X(m) is only
% calculated for the first m data points.
 
maxn = length(X);
Xavg = zeros(1,maxn);
Xstd = zeros(1,maxn);
% first element
Xavg(1) = X(1);
Xstd(1) = 0;
% elements 2 to n
for m = 2:n
    Xavg(m) = 1/m*( (m-1)*Xavg(m-1) + X(m) );
    Xstd(m) = sqrt( (m-2)/(m-1)*Xstd(m-1)^2 + 1/m*(X(m) - Xavg(m-1))^2 );
end
% elements n+1 to maxn
for m = (n+1):maxn
    Xavg(m) = Xavg(m-1) + 1/n*(X(m) - X(m-n));
    Xstd(m) = sqrt( Xstd(m-1)^2 + 1/(n-1)*( (X(m) - Xavg(m-1))^2 - (X(m-n) - Xavg(m-1))^2 ) - 1/(n-1)/n*(X(m) - X(m-n))^2 );
end
Xavg=Xavg';
Xstd=Xstd';
stats = [Xavg' Xstd'];
